@@ -3,7 +3,6 @@ use strict;
 use JSON::RPC::Constants qw(:all);
 use JSON::RPC::Parser;
 use JSON::RPC::Procedure;
-use Class::Load ();
 use Router::Simple;
 use Scalar::Util;
 use Try::Tiny;
@@ -32,7 +31,6 @@ sub new {
         $self->{parser} = JSON::RPC::Parser->new( coder => $self->coder )
     }
     if (! $self->{router}) {
-        require Router::Simple;
         $self->{router} = Router::Simple->new;
     }
     return $self;
@@ -50,7 +48,8 @@ sub construct_handler {
 
     my $handler = $self->handlers->{ $klass };
     if (! $handler) {
-        Class::Load::load_class( $klass );
+        eval "require $klass";
+        die if $@;
         $handler = $klass->new();
         $self->handlers->{$klass} = $handler;
     }
@@ -213,10 +212,39 @@ sub handle_psgi {
         $self->coder->encode( @$procedures > 1 ? \@response : $response[0] )
     );
 
-    return $res;
+    return $res->finalize;
 }
 
 no Try::Tiny;
 
 1;
 
+__END__
+
+=head1 NAME
+
+JSON::RPC::Dispatch - Dispatch JSON RPC Requests To Handlers
+
+=head1 SYNOPSIS
+
+    use JSON::RPC::Dispatch;
+
+    my $router = Router::Simple->new; # or use Router::Simple::Declare
+    $router->connect( method_name => {
+        handler => $class_name_or_instance,
+        action  => $method_name_to_invoke
+    );
+
+    my $dispatch = JSON::RPC::Dispatch->new(
+        router => $router
+    );
+
+    sub psgi_app {
+        $dispatch->handle_psgi( $env );
+    }
+
+=head1 DESCRIPTION
+
+See docs in L<JSON::RPC> for details
+
+=cut
